==> node-babel7_7.17.2%2B~cs214.260.190.orig.tar.xz: babel-7.17.2/packages/babel-plugin-proposal-private-methods/test/fixtures/static-accessors/updates/output.js <==
class Cl {
  static publicGetPrivateField() {
    return babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue);
  }

  static publicSetPrivateField(newValue) {
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, newValue);
  }

  static get publicFieldValue() {
    return Cl.publicField;
  }

  static set publicFieldValue(newValue) {
    Cl.publicField = newValue;
  }

  static testUpdates() {
    var _Cl$privateFieldValue, _Cl$privateFieldValue2;

    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateField, 0);
    Cl.publicField = 0;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, (babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, (_Cl$privateFieldValue2 = +babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue)) + 1), _Cl$privateFieldValue2));
    Cl.publicFieldValue = Cl.publicFieldValue++;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, +babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue) + 1);
    ++Cl.publicFieldValue;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue) + 1);
    Cl.publicFieldValue += 1;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, -(babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue) ** babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue)));
    Cl.publicFieldValue = -(Cl.publicFieldValue ** Cl.publicFieldValue);
  }

}

function _get_privateFieldValue() {
  return babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateField);
}

function _set_privateFieldValue(newValue) {
  babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateField, newValue);
}

var _privateFieldValue = {
  get: _get_privateFieldValue,
  set: _set_privateFieldValue
};
var _privateField = {
  writable: true,
  value: "top secret string"
};
babelHelpers.defineProperty(Cl, "publicField", "not secret string");

==> node-babel7_7.18.9%2B~cs214.249.185.orig.tar.xz: babel-7.18.9/packages/babel-plugin-proposal-private-methods/test/fixtures/static-accessors/updates/output.js <==
class Cl {
  static publicGetPrivateField() {
    return babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue);
  }

  static publicSetPrivateField(newValue) {
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, newValue);
  }

  static get publicFieldValue() {
    return Cl.publicField;
  }

  static set publicFieldValue(newValue) {
    Cl.publicField = newValue;
  }

  static testUpdates() {
    var _Cl$privateFieldValue, _Cl$privateFieldValue2, _Cl$privateFieldValue3, _Cl$privateFieldValue4, _Cl$privateFieldValue5;

    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateField, 0);
    Cl.publicField = 0;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, (babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, (_Cl$privateFieldValue3 = babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue), _Cl$privateFieldValue4 = _Cl$privateFieldValue3++, _Cl$privateFieldValue3)), _Cl$privateFieldValue4));
    Cl.publicFieldValue = Cl.publicFieldValue++;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, (_Cl$privateFieldValue5 = babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue), ++_Cl$privateFieldValue5));
    ++Cl.publicFieldValue;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue) + 1);
    Cl.publicFieldValue += 1;
    babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateFieldValue, -(babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue) ** babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateFieldValue)));
    Cl.publicFieldValue = -(Cl.publicFieldValue ** Cl.publicFieldValue);
  }

}

function _get_privateFieldValue() {
  return babelHelpers.classStaticPrivateFieldSpecGet(Cl, Cl, _privateField);
}

function _set_privateFieldValue(newValue) {
  babelHelpers.classStaticPrivateFieldSpecSet(Cl, Cl, _privateField, newValue);
}

var _privateFieldValue = {
  get: _get_privateFieldValue,
  set: _set_privateFieldValue
};
var _privateField = {
  writable: true,
  value: "top secret string"
};
babelHelpers.defineProperty(Cl, "publicField", "not secret string");
